# ar-crm-groups

> Your project description goes here

> Note:
This branch also uses [ar-crm-super](https://bitbucket.org/arteria/ar-crm-super/src/). It supports having people and companies as members (cura).

Versions in legacy should be <=0.0.99 to avoid conflicts with the master branch.
